import { closeConnection } from './closeConnection';
import { sendResponse } from './sendResponse';
export class WsApi {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    routeHandlers = {
        '$connect': () => Promise.resolve(),
        '$disconnect': () => Promise.resolve(),
    };
    addRouteHandler(routeHandler) {
        this.routeHandlers[routeHandler.route.action] = routeHandler.requestHandler;
        return this;
    }
    async handleRequest(event) {
        const { connectionId, domainName, stage, eventType } = event.requestContext;
        if (!eventType)
            throw 'No eventType';
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        let request;
        switch (eventType) {
            case 'CONNECT':
                request = { action: '$connect' };
                break;
            case 'DISCONNECT':
                request = { action: '$disconnect' };
                break;
            case 'MESSAGE':
                if (!event.body)
                    throw 'No body';
                request = JSON.parse(event.body);
                break;
            default:
                throw `Unknown eventType ${eventType}`;
        }
        const endpoint = `https://${domainName}/${stage}`;
        const connection = { endpoint, connectionId };
        const requestHandler = this.routeHandlers[request.action];
        if (!requestHandler) {
            await closeConnection(connection);
            throw `No requestHandler found for action ${request.action}`;
        }
        await requestHandler(request, {
            connection,
            sendResponse: async (response) => await sendResponse(connection, response),
            closeConnection: async () => await closeConnection(connection),
        });
        return {
            statusCode: 200,
            body: '',
        };
    }
}
//# sourceMappingURL=WsApi.js.map