import { PostToConnectionCommand } from '@aws-sdk/client-apigatewaymanagementapi';
import { callTRPCProcedure } from '@trpc/server';
import { getApiGatewayManagementApiClient } from './getApiGatewayManagementApiClient';
import { getConnection } from './getConnection';
export const awsLambdaTrpcSubscriptionRequestHandler = (opts) => {
    const { router } = opts;
    return async (event) => {
        try {
            const connection = getConnection(event);
            if (!event.body || event.body === '[]')
                return { statusCode: 200, body: '' };
            const request = JSON.parse(event.body);
            const sendMessage = async (response) => {
                await getApiGatewayManagementApiClient(connection.endpoint).send(new PostToConnectionCommand({
                    ConnectionId: connection.connectionId,
                    Data: JSON.stringify(response),
                }));
            };
            const stopConnection = async () => {
                await sendMessage({
                    id: request.id,
                    result: { type: 'stopped' },
                });
            };
            if (request.method === 'subscription.stop') {
                await stopConnection();
            }
            if (request.method === 'subscription') {
                await sendMessage({
                    id: request.id,
                    result: { type: 'started' },
                });
                const sub = (await callTRPCProcedure({
                    procedures: router._def.procedures,
                    path: request.params.path,
                    type: 'subscription',
                    ctx: {},
                    getRawInput: async () => request.params.input,
                }));
                await new Promise((resolve) => {
                    sub.subscribe({
                        next: async (data) => await sendMessage({
                            id: request.id,
                            result: {
                                type: 'data',
                                data: data,
                            },
                        }),
                        error: async (err) => {
                            console.error(err);
                            await stopConnection();
                            resolve();
                        },
                        complete: async () => {
                            await stopConnection();
                            resolve();
                        },
                    });
                });
            }
        }
        catch (err) {
            console.error(err);
        }
        return {
            statusCode: 200,
            body: '',
        };
    };
};
//# sourceMappingURL=awsLambdaTrpcSubscriptionRequestHandler.js.map